package org.eclipse.jdt.internal.compiler.parser;

package .tmp;

import java.util.HashSet;
import java.util.Set;
import org.eclipse.jdt.internal.compiler.ast.ASTNode;
import org.eclipse.jdt.internal.compiler.ast.Statement;
import org.eclipse.jdt.internal.compiler.ast.TypeDeclaration;
import org.eclipse.jdt.internal.compiler.parser.RecoveredElement;

public class RecoveredStatement extends RecoveredElement {
  public Statement statement;
  
  public RecoveredStatement(Statement statement, RecoveredElement parent, int bracketBalance) {
    super(parent, bracketBalance);
    this.statement = statement;
  }
  
  public ASTNode parseTree() {
    return (ASTNode)this.statement;
  }
  
  public int sourceEnd() {
    return this.statement.sourceEnd;
  }
  
  public String toString(int tab) {
    return String.valueOf(tabString(tab)) + "Recovered statement:\n" + this.statement.print(tab + 1, new StringBuffer(10));
  }
  
  public Statement updatedStatement(int depth, Set<TypeDeclaration> knownTypes) {
    return this.statement;
  }
  
  public void updateParseTree() {
    updatedStatement(0, new HashSet<>());
  }
  
  public void updateSourceEndIfNecessary(int bodyStart, int bodyEnd) {
    if (this.statement.sourceEnd == 0)
      this.statement.sourceEnd = bodyEnd; 
  }
  
  public RecoveredElement updateOnClosingBrace(int braceStart, int braceEnd) {
    if (--this.bracketBalance <= 0 && this.parent != null) {
      updateSourceEndIfNecessary(braceStart, braceEnd);
      return this.parent.updateOnClosingBrace(braceStart, braceEnd);
    } 
    return this;
  }
}
